Presto-Admin
============

`Presto Community <https://prestosql.io/community.html>`_ |
`Issues <https://github.com/prestosql/presto-admin/issues>`_ |
`Github <https://github.com/prestosql/presto-admin>`_ |

Introduction
------------
Presto-Admin is a tool for installing and managing the Presto query engine on a
cluster. It provides easy-to-use commands to:

    * Install and uninstall Presto across your cluster
    * Configure your Presto cluster
    * Start and stop the Presto servers
    * Gather status and log information from your Presto cluster

Content
-------

.. toctree::
   :maxdepth: 3

   software-requirements
   user-guide
   contributing
   release

.. toctree::
   :hidden:

   modules

Indices and tables
------------------

* :ref:`search`

